@@ -28,7 +28,7 @@ import time
 from typing import Iterable, Union as _Union
 from typing import Iterable as _Iterable
 
-import mysql.connector
+import mysql.connector as _mysqlConnector
 import traceback as _traceback
 from mysql.connector import Error
 from colorama import Fore as _Fore
@@ -183,7 +183,7 @@ class MySQLDatabase:
         if self._credentials:
             self.con = None
             try:
-                self.con = mysql.connector.connect(
+                self.con = _mysqlConnector.connect(
                     database =self.database,
                     user =self.user,
                     password =self.password,
@@ -483,11 +483,11 @@ class MySQLDatabase:
             success = True
 
 
-        except mysql.connector.errors.IntegrityError:
+        except _mysqlConnector.errors.IntegrityError:
             _log(f"{_traceback.format_exc()}","error")
             _log(f"SQL: {sql}","error")
 
-        except mysql.connector.errors.InterfaceError:
+        except _mysqlConnector.errors.InterfaceError:
             if isTimeoutRetry is True:
                 _log(f"{_traceback.format_exc()}","error")
                 _log(f"SQL: {sql}","error")
@@ -498,7 +498,7 @@ class MySQLDatabase:
                 self.connect()
                 return self.execute_single_statement(sql,args,True)
 
-        except mysql.connector.errors.DatabaseError:
+        except _mysqlConnector.errors.DatabaseError:
             # print(f"ERROR: {err}", PRESET="FATAL_ERROR_INVERT")
             _log(f"{_traceback.format_exc()}","error")
             _log(f"SQL: {sql}","error")
